<!DOCTYPE kpartgui>
<kpartplugin name="karpion" library="libkarpionplugin" version="1">
<MenuBar>
 <Menu name="tools"><Text>&amp;Tools</Text>
   <Menu name="karpionmenu"><Text>Anti-Phishing</Text>
     <Action name="karpion_siteinfo"/>
     <Separator/>
     <Action name="karpion_reportphishing"/>
     <Action name="karpion_addsafelist"/>
     <Separator/>
     <Action name="karpion_configure"/>
     <Separator/>
     <Action name="karpion_about"/>
   </Menu>
 </Menu>
</MenuBar>
<ToolBar name="karpionToolBar"><Text>Anti-Phishing</Text>
  <Action name="karpion_sitemenu"/>
  <Separator/>
  <Action name="karpion_risklabel"/>
  <Action name="karpion_siteinfo"/>
  <Separator/>
  <Action name="karpion_countrylabel"/>
</ToolBar>
</kpartplugin>
